@@ -15,7 +15,7 @@
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Stub for Apport"""
 
-from apport.packaging import is_distro_package
+import apport.packaging
 
 
 def add_info(report):
